Group: System/Libraries
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-cmake rpm-macros-fedora-compat
BuildRequires: /usr/bin/gconftool-2 openmpi-devel
# END SourceDeps(oneline)
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
%global		soversion	2.1

Name:		nvidia-texture-tools
Version:	2.1.2
Release:	alt1_2
Summary:	Collection of image processing and texture manipulation tools
License:	MIT and ASL 2.0 and BSD
URL:		https://github.com/castano/nvidia-texture-tools/wiki
Source0:	https://github.com/castano/%{name}/archive/%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:	ctest cmake
BuildRequires:	help2man
BuildRequires:	libjpeg-devel
BuildRequires:	libpng-devel libpng17-tools
BuildRequires:	libtiff-devel libtiffxx-devel
BuildRequires:	libopenjpeg-devel
BuildRequires:	libGL-devel
BuildRequires:	libGLU-devel

Patch0:		%{name}-libs.patch
Patch1:		%{name}-check.patch
Patch2:		%{name}-docs.patch
# add MIPS support
Patch3:		%{name}-mips.patch
# add S390 support
Patch4:		%{name}-s390.patch
# add PPCLE support
Patch5:		%{name}-ppcle.patch
# add aarch64 support
Patch6:		%{name}-aarch64.patch
# Do not presume SSE is available
Patch7:		%{name}-simd.patch
# Do not force compiler flags
Patch8:		%{name}-flags.patch
# Only implemented for x86
Patch9:		%{name}-debug.patch
Source44: import.info
ExcludeArch: %ix86

%description
The NVIDIA Texture Tools is a collection of image processing and texture
manipulation tools, designed to be integrated in game tools and asset
conditioning pipelines.

The primary features of the library are mipmap and normal map generation,
format conversion and DXT compression.

DXT compression is based on Simon Brown's squish library. The library also
contains an alternative GPU-accelerated compressor that uses CUDA and is
one order of magnitude faster.

%package	devel
Group: Development/Other
Summary:	Development libraries/headers for %{name}
Requires:	%{name} = %{version}-%{release}

%description	devel
Headers and libraries for development with %{name}.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p0
%patch5 -p0
%patch6 -p0
%patch7 -p0
%patch8 -p0
%ifnarch %{ix86} x86_64
%patch9 -p0
%endif

%build
%{fedora_v2_cmake} -DNVTT_SHARED=1 -DCMAKE_SKIP_RPATH=1	\
%ifnarch %{ix86} x86_64
	-DBUILD_SQUISH_WITH_SSE2=OFF		\
%endif
%if 0
%ifarch ppc64 ppc64le
	-DBUILD_SQUISH_WITH_ALTIVEC=ON		\
%endif
%endif

%fedora_v2_cmake_build

sed -e 's/\r//' -i LICENSE

%install
%fedora_v2_cmake_install
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man1
pushd $RPM_BUILD_ROOT/%{_bindir}
    export LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{_libdir}:
    for bin in *; do
	help2man --no-info ./$bin > $RPM_BUILD_ROOT/%{_mandir}/man1/$bin.1
    done
popd

%check
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{_libdir}:
%fedora_v2_ctest



%files
%doc --no-dereference LICENSE
%doc README.md
%{_bindir}/*
%{_libdir}/lib*.%{version}
%{_libdir}/lib*.%{soversion}
%{_mandir}/man1/*

%files		devel
%doc ChangeLog
%{_includedir}/nvtt
%{_libdir}/lib*.so

%changelog
* Wed Oct 27 2021 Igor Vlasenko <viy@altlinux.org> 2.1.2-alt1_2
- update

* Wed Jan 27 2021 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt2_25
- update to new release by fcimport

* Sun Nov 01 2020 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_25
- update to new release by fcimport

* Thu Mar 05 2020 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_22
- update to new release by fcimport

* Tue Aug 06 2019 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_21
- update to new release by fcimport

* Fri Mar 01 2019 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_20
- update to new release by fcimport

* Wed Aug 01 2018 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_19
- update to new release by fcimport

* Fri Jun 08 2018 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_18
- update to new release by fcimport

* Mon Feb 05 2018 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_17
- update to new release by fcimport

* Sun May 29 2016 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_13
- update to new release by fcimport

* Mon Sep 21 2015 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_11
- update to new release by fcimport

* Wed Sep 10 2014 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_9
- update to new release by fcimport

* Thu Jun 26 2014 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_7
- update to new release by fcimport

* Mon Aug 05 2013 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_6
- update to new release by fcimport

* Fri Apr 26 2013 Igor Vlasenko <viy@altlinux.ru> 2.0.8-alt1_5
- initial fc import

